@@ -416,14 +416,12 @@ def _plot_heatmap(
 ) -> alt.Chart:
     metric_data = alt.Data(
         values=[
-            *[
-                {
-                    **_core_plot_data(cell),
-                    **_calculate_field_summary(cell, prev_cell, metric, "metric"),
-                    "Field": name,
-                }
-                for cell, prev_cell in zip(triangle, [None, *triangle[:-1]])
-            ]
+            {
+                **_core_plot_data(cell),
+                **_calculate_field_summary(cell, prev_cell, metric, "metric"),
+                "Field": name,
+            }
+            for cell, prev_cell in zip(triangle, [None, *triangle[:-1]])
         ]
     )
 
@@ -540,8 +538,14 @@ def _plot_atas(
         rule=alt.MarkConfig(stroke="black"),
         box=alt.MarkConfig(stroke="black"),
     )
+    errors = base.mark_errorbar(thickness=1).encode(
+        y=alt.Y("metric_lower_ci:Q").axis(title=name),
+        y2=alt.Y2("metric_upper_ci:Q"),
+        color=alt.value("black"),
+        opacity=alt.value(0.7),
+    )
 
-    return (points + boxplot).interactive()
+    return (points + errors + boxplot).interactive()
 
 
 def plot_growth_curve(
@@ -611,7 +615,7 @@ def _plot_growth_curve(
                 )
                 for i, value in enumerate(
                     _scalar_or_array_to_iter(
-                        _safe_apply_metric(cell, prev_cell, metric, "")
+                        _safe_apply_metric(cell, prev_cell, metric)
                     )
                 )
             ]
@@ -862,6 +866,7 @@ def plot_mountain(
     height: int = 200,
     ncols: int | None = None,
     facet_titles: list[str] | None = None,
+    highlight_ultimates: bool = True,
 ) -> alt.Chart:
     """Plot triangle metrics as a mountain."""
     main_title = alt.Title(
@@ -871,6 +876,7 @@ def plot_mountain(
     n_metrics = len(metric_dict)
     n_slices = len(triangle.slices)
     max_cols = ncols or _determine_facet_cols(n_slices * n_metrics)
+    legend_direction = "horizontal" if highlight_ultimates else "vertical"
     fig = (
         _build_metric_slice_charts(
             triangle,
@@ -878,6 +884,7 @@ def plot_mountain(
             metric_dict=metric_dict,
             uncertainty=uncertainty,
             uncertainty_type=uncertainty_type,
+            highlight_ultimates=highlight_ultimates,
             mark_scaler=max_cols,
             title=main_title,
             facet_titles=facet_titles,
@@ -886,7 +893,7 @@ def plot_mountain(
             ncols=max_cols,
         )
         .configure_axis(**_compute_font_sizes(max_cols))
-        .configure_legend(**_compute_font_sizes(max_cols))
+        .configure_legend(**_compute_font_sizes(max_cols), direction=legend_direction)
     )
     return fig.interactive()
 
@@ -899,27 +906,44 @@ def _plot_mountain(
     mark_scaler: int,
     uncertainty: bool,
     uncertainty_type: Literal["ribbon", "segments"],
+    highlight_ultimates: bool = True,
 ) -> alt.Chart:
+    metric_triangle = (
+        triangle.clip(max_dev=triangle.dev_lags()[-2])
+        if highlight_ultimates
+        else triangle
+    )
     metric_data = alt.Data(
         values=[
-            *[
-                {
-                    **_core_plot_data(cell),
-                    "last_lag": max(
-                        triangle.filter(lambda ob: ob.period == cell.period).dev_lags()
-                    ),
-                    **_calculate_field_summary(cell, prev_cell, metric, "metric"),
-                    "Field": name,
-                }
-                for cell, prev_cell in zip(triangle, [None, *triangle[:-1]])
-            ]
+            {
+                **_core_plot_data(cell),
+                "last_lag": max(
+                    triangle.filter(lambda ob: ob.period == cell.period).dev_lags()
+                ),
+                **_calculate_field_summary(cell, prev_cell, metric, "metric"),
+                "Field": name,
+            }
+            for cell, prev_cell in zip(metric_triangle, [None, *metric_triangle[:-1]])
         ]
     )
 
+    if highlight_ultimates:
+        ultimate_triangle = triangle.right_edge
+        ultimate_data = alt.Data(
+            values=[
+                {
+                    **_core_plot_data(cell),
+                    **_calculate_field_summary(cell, prev_cell, metric, "metric"),
+                    "Field": name,
+                }
+                for cell, prev_cell in zip(
+                    ultimate_triangle, [None, *ultimate_triangle[:-1]]
+                )
+            ]
+        )
+
     color = (
-        alt.Color("dev_lag:Q")
-        .scale(range=MANAGUA_VALS)
-        .legend(title="Development Lag (months)")
+        alt.Color("dev_lag:Q").scale(range=MANAGUA_VALS).legend(title="Development Lag")
     )
     color_none = color.legend(None)
 
@@ -927,30 +951,26 @@ def _plot_mountain(
     opacity_conditional = (
         alt.when(selector).then(alt.OpacityValue(1)).otherwise(alt.OpacityValue(0.2))
     )
-    color_conditional = alt.when(selector).then(color).otherwise(alt.value("lightgray"))
-    color_conditional_no_legend = (
-        alt.when(selector).then(color_none).otherwise(alt.value("lightgray"))
-    )
+
+    tooltip = [
+        alt.Tooltip("period_start:T", title="Period Start"),
+        alt.Tooltip("period_end:T", title="Period End"),
+        alt.Tooltip("evaluation_date:T", title="Evaluation Date"),
+        alt.Tooltip("dev_lag:Q", title="Dev Lag (months)"),
+        alt.Tooltip("metric:Q", format=",.1f", title=name),
+    ]
 
     base = alt.Chart(metric_data, title=title).encode(
         x=alt.X(
             "yearmonth(period_start):O", axis=alt.Axis(grid=True, labelAngle=0)
         ).title("Period Start"),
         y=alt.X("metric:Q").title(name),
-        tooltip=[
-            alt.Tooltip("period_start:T", title="Period Start"),
-            alt.Tooltip("period_end:T", title="Period End"),
-            alt.Tooltip("evaluation_date:T", title="Evaluation Date"),
-            alt.Tooltip("dev_lag:Q", title="Dev Lag (months)"),
-            alt.Tooltip("metric:Q", format=",.1f", title=name),
-        ],
+        tooltip=tooltip,
     )
 
-    lines = base.mark_line().encode(
-        color=color_conditional_no_legend, opacity=opacity_conditional
-    )
+    lines = base.mark_line().encode(color=color_none, opacity=opacity_conditional)
     points = base.mark_point(filled=True, stroke=None).encode(
-        color=color_conditional,
+        color=color,
         opacity=opacity_conditional,
     )
 
@@ -963,22 +983,58 @@ def _plot_mountain(
         errors = base.mark_area().encode(
             y=alt.Y("metric_lower_ci:Q"),
             y2=alt.Y2("metric_upper_ci:Q"),
-            color=color_conditional_no_legend,
+            color=color_none,
             opacity=ribbon_conditional,
         )
     elif uncertainty and uncertainty_type == "segments":
         errors = base.mark_errorbar(thickness=5).encode(
             y=alt.Y("metric_lower_ci:Q").axis(title=name),
             y2=alt.Y2("metric_upper_ci:Q"),
-            color=color_conditional_no_legend,
+            color=color_none,
             opacity=opacity_conditional,
         )
     else:
         errors = alt.LayerChart()
 
-    return alt.layer(errors + lines, points.add_params(selector)).resolve_scale(
-        color="independent"
-    )
+    if highlight_ultimates:
+        ultimate_color = alt.Color("dev_lag:Q").scale(scheme="greys")
+        ultimate_base = alt.Chart(ultimate_data).encode(
+            x=alt.X(
+                "yearmonth(period_start):O", axis=alt.Axis(grid=True, labelAngle=0)
+            ).title("Period Start"),
+            y=alt.X("metric:Q").title(name),
+            tooltip=tooltip,
+            order=alt.value(1),
+        )
+        ultimates = ultimate_base.mark_line().encode(
+            color=ultimate_color.legend(title="Ultimate Lag")
+        )
+        ultimates += ultimate_base.mark_point(filled=True).encode(
+            color=ultimate_color,
+        )
+
+        if uncertainty and uncertainty_type == "ribbon":
+            ultimates += ultimate_base.mark_area().encode(
+                y=alt.Y("metric_lower_ci:Q"),
+                y2=alt.Y2("metric_upper_ci:Q"),
+                color=ultimate_color,
+                opacity=ribbon_conditional,
+            )
+        if uncertainty and uncertainty_type == "segments":
+            ultimates += ultimate_base.mark_errorbar(thickness=5).encode(
+                y=alt.Y("metric_lower_ci:Q").axis(title=name),
+                y2=alt.Y2("metric_upper_ci:Q"),
+                color=ultimate_color,
+                opacity=opacity_conditional,
+            )
+    else:
+        ultimates = alt.LayerChart()
+
+    return alt.layer(
+        lines + errors,
+        points.add_params(selector),
+        ultimates,
+    ).resolve_scale(color="independent")
 
 
 def plot_ballistic(
@@ -1497,7 +1553,7 @@ def _calculate_field_summary(
     name: str,
     probs: tuple[float, float] = (0.05, 0.95),
 ):
-    metric = _safe_apply_metric(cell, prev_cell, func, name)
+    metric = _safe_apply_metric(cell, prev_cell, func)
 
     if metric is None:
         return {
@@ -1525,21 +1581,16 @@ def _calculate_field_summary(
     }
 
 
-def _safe_apply_metric(cell: Cell, prev_cell: Cell | None, func: MetricFunc, name: str):
+def _safe_apply_metric(cell: Cell, prev_cell: Cell | None, func: MetricFunc):
     try:
         if prev_cell.period != cell.period:
             raise IndexError
         return func(cell, prev_cell)
-    except TypeError as e:
-        if "takes 1 positional argument but 2 were given" in e.args[0]:
-            try:
-                return func(cell)
-            except Exception:
-                return None
-        elif "'NoneType' object is not subscriptable" in e.args[0]:
-            return None
     except Exception:
-        return None
+        try:
+            return func(cell)
+        except Exception:
+            return None
 
 
 def _compute_font_sizes(mark_scaler: int) -> dict[str, float | int]:
